#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "emmathfnt.h"

#if macintosh || Macintosh || THINK_C || defined(_MAC) || defined(__MRC__)
#define MACOS_VERSION 1
#include <console.h>     /* Needed to get command line args on MacOS. */
#include "Files.h"       /* Needed for type/creator operations. */
#include "TextUtils.h"   /* Needed for type/creator operations. */
#endif

int main(int argc, char* argv[]) {

	char *infile, *outfile, *fontdir;
	FILE *stmin, *stmout;
	int i, c, retval;

#if MACOS_VERSION
	FSSpec spec;                     /* Macintosh file system specification */
	FInfo fndrInfo;                  /* Macintosh finder information records  */
	unsigned char theFullPath[255];  /* for conversion to Pascal string */
#endif 

/* Reads in command line args through a dialog box. */

#if MACOS_VERSION
argc = ccommand(&argv);
#endif 

/* 
* Process command line options 
*
* -o <filename>  output file
* -d <directory> path to Type 1 Math fonts
*
* If input or output file are not specified, default to stdin and stdout. 
*/ 
   
	infile = outfile = fontdir = NULL;

	if (argc > 1) { 
		for (i = 1; i < argc; ++i) {
			if (!strcmp(*(argv + i), "-o")) {
				outfile = (char *) malloc((strlen(*(argv +i + 1)) + 1) *
					sizeof(char));
				strcpy(outfile, *(argv + i + 1));
			}
			if (!strcmp(*(argv + i), "-d")) {
				fontdir = (char *) malloc((strlen(*(argv + i + 1)) + 1) *
					sizeof(char));
				strcpy(fontdir, *(argv + i + 1));
			}
		}
	}
	
	if (!(argc % 2) && (argc != 0)) {
		infile = (char *) malloc((strlen(*(argv + argc - 1)) + 1) * 
			sizeof(char));
		strcpy(infile, *(argv + argc - 1));
	}

	if (infile != NULL) {
		stmin = fopen(infile, "rb");
		if (stmin == NULL) {
			fprintf(stderr, "%s: Cannot find or open file %s.\n",
				*argv, infile);
			return -1;
		}
	} else {
		/* Dump stdin contents to a scratch file. emmathfnt() requires
		   random access to input data file. */
		stmin = tmpfile();
		while ((c = getchar()) != EOF) {
			putc(c, stmin);
		}
		rewind(stmin);
	}

	if (outfile != NULL) {
		stmout = fopen(outfile, "w");
		if (stmout == NULL) {
			fprintf(stderr, "%s: Can't find or open file %s.\n", 
				*argv, outfile);
			return -1;
		}
	} else {
		stmout = stdout;
	}

/* 
*
* Call API function for embedding font using EPS from stream stmin and 
* write output to stream stmout. 
*
*/
   
	retval = emmathfnt(stmin, stmout, fontdir);

	switch (retval) {
		case FONT_NOT_FOUND :
			fprintf(stderr, "%s: Cannot find Math font file or directory.\n", *argv);
			return FONT_NOT_FOUND; 
			break;
		case BAD_EPS_HEADER :
			fprintf(stderr, "%s: EPS header is not valid.\n", *argv);
			return BAD_EPS_HEADER;
			break;
		default :
			break;
	}

	if (stmout != stdout) {
		fclose(stmout);
#if MACOS_VERSION /* Set file type and creator for Macintosh. */
        strcpy((char *) theFullPath, outfile);
        c2pstr((char *) theFullPath);
        FSMakeFSSpec(0, 0L, theFullPath, &spec);
        FSpGetFInfo(&spec, &fndrInfo);
        fndrInfo.fdType = 'EPSF';      /* Encapsulated PostScript */
        fndrInfo.fdCreator = 'gsVR';   /* Mac Ghostscript  */
        FSpSetFInfo(&spec, &fndrInfo);
#endif

	}

	fclose(stmin);
	
	return 0;

}
